@@ -152,30 +152,16 @@ Rectangle getClientAreaInPixels () {
 
 @Override
 GdkRGBA getContextColorGdkRGBA () {
-	if (GTK.GTK_VERSION >= OS.VERSION (3, 14, 0)) {
-		if (foreground != null) {
-			return foreground;
-		} else {
-			return display.COLOR_WIDGET_FOREGROUND_RGBA;
-		}
+	if (foreground != null) {
+		return foreground;
 	} else {
-		return super.getContextColorGdkRGBA();
+		return display.COLOR_WIDGET_FOREGROUND_RGBA;
 	}
 }
 
 @Override
 GdkRGBA getContextBackgroundGdkRGBA () {
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		return super.getContextBackgroundGdkRGBA();
-	} else {
-		long context = GTK.gtk_widget_get_style_context (fixedHandle);
-		GdkRGBA rgba = new GdkRGBA ();
-		GTK.gtk_style_context_get_background_color (context, GTK.GTK_STATE_FLAG_NORMAL, rgba);
-		if ((state & BACKGROUND) == 0) {
-			return defaultBackground();
-		}
-		return rgba;
-	}
+	return super.getContextBackgroundGdkRGBA();
 }
 
 @Override
@@ -321,15 +307,6 @@ void releaseWidget () {
 	text = null;
 }
 
-@Override
-void setBackgroundGdkRGBA(long handle, GdkRGBA rgba) {
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 18, 0)) {
-		super.setBackgroundGdkRGBA(handle, rgba);
-	} else {
-		super.setBackgroundGdkRGBA(fixedHandle, rgba);
-	}
-}
-
 @Override
 void setFontDescription (long font) {
 	super.setFontDescription (font);
@@ -338,10 +315,6 @@ void setFontDescription (long font) {
 
 @Override
 void setForegroundGdkRGBA (long handle, GdkRGBA rgba) {
-	if (GTK.GTK_VERSION < OS.VERSION(3, 14, 0)) {
-		super.setForegroundGdkRGBA(handle, rgba);
-		return;
-	}
 	/*
 	 * When using CSS, setting the foreground color on an empty label
 	 * widget prevents the background from being set. If a user wants
@@ -411,7 +384,7 @@ public void setText (String string) {
 		GTK.gtk_frame_set_label_widget (handle, 0);
 	}
 	// Set the foreground now that the text has been set
-	if (GTK.GTK_VERSION >= OS.VERSION (3, 16, 0) && foreground != null) {
+	if (foreground != null) {
 		setForegroundGdkRGBA (labelHandle, foreground);
 	}
 }
@@ -437,30 +410,22 @@ int setBounds(int x, int y, int width, int height, boolean move, boolean resize)
 	 * elements which we cannot access. If the to-be-allocated size minus
 	 * these elements is < 0, allocate the preferred size instead.
 	 */
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
-		width = (width - (requisition.width - width)) < 0 ? requisition.width : width;
-		height = (height - (requisition.height - height)) < 0 ? requisition.height : height;
-	} else {
-		width = Math.max(requisition.width, width);
-	}
+	width = (width - (requisition.width - width)) < 0 ? requisition.width : width;
+	height = (height - (requisition.height - height)) < 0 ? requisition.height : height;
 	return super.setBounds(x, y, width, height, move, resize);
 }
 
 @Override
 long paintHandle() {
-	if (GTK.GTK_VERSION < OS.VERSION(3, 14, 0)) {
-		return super.paintHandle();
-	} else {
-		if (GTK.GTK4) return clientHandle;
-		long topHandle = topHandle ();
-		/* we draw all our children on the clientHandle*/
-		long paintHandle = clientHandle;
-		while (paintHandle != topHandle) {
-			if (gtk_widget_get_has_surface_or_window (paintHandle)) break;
-			paintHandle = GTK.gtk_widget_get_parent (paintHandle);
-		}
-		return paintHandle;
+	if (GTK.GTK4) return clientHandle;
+	long topHandle = topHandle ();
+	/* we draw all our children on the clientHandle*/
+	long paintHandle = clientHandle;
+	while (paintHandle != topHandle) {
+		if (gtk_widget_get_has_surface_or_window (paintHandle)) break;
+		paintHandle = GTK.gtk_widget_get_parent (paintHandle);
 	}
+	return paintHandle;
 }
 
 @Override
