@@ -30,6 +30,8 @@ import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Device;
 import org.eclipse.swt.graphics.Point;
+import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Text;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -64,8 +66,8 @@ public void test_ConstructorLorg_eclipse_swt_widgets_CompositeI() {
 		ccombo = new CCombo(shell, SWT.BORDER | SWT.READ_ONLY);
 		// Test all the combo listeners
 		int comboListeners[] = { SWT.Dispose, SWT.FocusIn, SWT.Move, SWT.Resize };
-		for (int i = 0; i < comboListeners.length; i++) {
-			assertTrue("Combo Listener events not implemented", ccombo.getListeners(comboListeners[i]).length > 0);
+		for (int comboListener : comboListeners) {
+			assertTrue("Combo Listener events not implemented", ccombo.getListeners(comboListener).length > 0);
 		}
 		assertTrue("Pop up items are present.", ccombo.getItems().length == 0);
 		// test that accessible features are added
@@ -194,6 +196,8 @@ public void test_setEnabledZ() {
 @Test
 public void test_setFocus() {
 	assertTrue(!ccombo.setFocus());
+	shell.open();
+	shell.setVisible(true);
 	boolean exceptionThrown = false;
 	try{
 		ccombo.setEnabled(false);
@@ -207,8 +211,20 @@ public void test_setFocus() {
 		assertFalse("Expect false wehn not visible and not enabled", ccombo.setFocus());
 		ccombo.setEnabled(true);
 		ccombo.setVisible(true);
+		processEvents(0, null);
 		if(ccombo.isFocusControl())
 			assertTrue("Set focus error", ccombo.setFocus());
+
+		if (!SwtTestUtil.isCocoa) {
+			ccombo.setEnabled(true);
+			ccombo.setVisible(true);
+			ccombo.setFocus();
+			processEvents(0, null);
+			assertTrue(ccombo.isFocusControl());
+			Control focusControl = ccombo.getDisplay().getFocusControl();
+			assertTrue(focusControl instanceof Text);
+			assertEquals(ccombo, focusControl.getParent());
+		}
 	}
 	catch (Exception e) {
 		exceptionThrown = true;
@@ -1029,4 +1045,24 @@ public void test_setTextLjava_lang_String() {
 		assertTrue(":c:" + i, ccombo.getText().equals(cases[i]));
 	}
 }
+
+@Test
+public void test_setAlignment() {
+	assertEquals(":a:", SWT.LEAD, ccombo.getAlignment());
+
+	ccombo.setText("Trail");
+	ccombo.setAlignment(SWT.TRAIL);
+	assertEquals(":b:", SWT.TRAIL, ccombo.getAlignment());
+	assertEquals(":b:", "Trail", ccombo.getText());
+
+	ccombo.add("Center");
+	ccombo.select(ccombo.getItemCount() - 1);
+	ccombo.setAlignment(SWT.CENTER);
+	assertEquals(":c:", SWT.CENTER, ccombo.getAlignment());
+	assertEquals(":c:", "Center", ccombo.getText());
+
+	ccombo.setAlignment(SWT.LEFT);
+	assertEquals(":d:", SWT.LEFT, ccombo.getAlignment());
+	assertEquals(":d:", "Center", ccombo.getText());
+}
 }
